import { useState } from "react";
import { Link } from "react-router-dom";
import { Container, Stack, Button, Modal, Form } from "react-bootstrap";

import { useAppDispatch, useAppSelector } from "./hooks";
import { addPathToSignature, selectSignature } from "./store/contestantSlice";

import DrawPad from "./DrawPad";

const Landing = () => {
  const [isContestant, setIsContestant] = useState(false);
  const [isHost, setIsHost] = useState(false);
  const [roomCode, setRoomCode] = useState("");
  const dispatch = useAppDispatch();
  const signature = useAppSelector(selectSignature);

  return (
    <>
      <Container>
        <Stack gap={3} className="text-center">
          <h1>Venture</h1>
          <Link to={"/new-game"}>
            <Button>New Game</Button>
          </Link>
          <span>
            <Button onClick={() => setIsContestant(true)}>
              Join as Contestant
            </Button>
          </span>
          <span>
            <Button onClick={() => setIsHost(true)}>Join as Host</Button>
          </span>
        </Stack>
      </Container>
      <Modal show={isContestant}>
        <Modal.Body>
          <Form className="text-center">
            <Form.Group className="text-start">
              <Form.Label>Room Code</Form.Label>
              <Form.Control
                type={"text"}
                value={roomCode}
                onChange={(e) => setRoomCode(e.target.value)}
              />
            </Form.Group>
            <Form.Group className="text-start">
              <Form.Label>Name</Form.Label>
              <DrawPad
                height={200}
                lines={signature}
                onUpdateImage={(path: number[]) =>
                  dispatch(addPathToSignature(path))
                }
              />
            </Form.Group>
            <Link to={`/contestant-join/${roomCode}`}>
              <Button className="m-3">Submit</Button>
            </Link>
          </Form>
        </Modal.Body>
      </Modal>
      <Modal show={isHost}>
        <Modal.Body>
          <Form className="text-center">
            <Form.Group className="text-start">
              <Form.Label>Room Code</Form.Label>
              <Form.Control
                type={"text"}
                value={roomCode}
                onChange={(e) => setRoomCode(e.target.value)}
              />
            </Form.Group>
            <Link to={`/host-join/${roomCode}`}>
              <Button className="m-3">Submit</Button>
            </Link>
          </Form>
        </Modal.Body>
      </Modal>
    </>
  );
};

export default Landing;
