import { createSlice, PayloadAction } from "@reduxjs/toolkit";
import type { RootState } from "./";

interface ContestantState {
  signature: number[][];
  canBuzz: boolean;
}

const initialState: ContestantState = {
  signature: [],
  canBuzz: false,
};

export const contestantSlice = createSlice({
  name: "contestant",
  initialState,
  reducers: {
    addPathToSignature: (state, { payload }: PayloadAction<number[]>) => {
      state.signature = [...state.signature, payload];
    },
    setCanBuzz: (state, { payload }: PayloadAction<boolean>) => {
      state.canBuzz = payload;
    },
  },
});

export const { addPathToSignature } = contestantSlice.actions;
export const selectSignature = (state: RootState) => state.contestant.signature;
export const selectCanBuzz = (state: RootState) => state.contestant.canBuzz;

export default contestantSlice.reducer;
